@@ -4,7 +4,7 @@ function(web, plot.it=TRUE, pure.call=TRUE, silent=TRUE){
     # calculates cumulative degree distributions and fits exponential, power law
     # and truncated power law functions to it
     # return fits
- 	 web <- empty(web)
+ 	web <- empty(web)
     web <- (web>0)*1 #turns it into a qualitative network
     k <- sum(web) # number of links in network
     S <- sum(dim(web)) # number of species in network
@@ -13,14 +13,15 @@ function(web, plot.it=TRUE, pure.call=TRUE, silent=TRUE){
 
     Plo <- sapply(sort(unique(ddlower)), function(x) sum(ddlower>=x))
     Plower <- cbind.data.frame(k=sort(unique(ddlower)), P=Plo/max(Plo))
-    if (nrow(Plower) < 5) warning("Too few data points (< 5) for lower trophic level! Fitting makes no sense! The truncated fit is the first to fail because it has a parameter more.")
+    if (nrow(Plower) < 5) warning("Too few data points (< 5) for lower trophic level! Fitting makes no sense! The truncated fit is the first to fail because it has one parameter more.")
     Phi <- sapply(sort(unique(ddhigher)), function(x) sum(ddhigher>=x))
     Phigher <- cbind.data.frame(k=sort(unique(ddhigher)), P=Phi/max(Phi))
-    if (max(Phigher) < 5) warning("Too few data levels of degrees (< 5) for higher trophic level! Fitting makes no sense! The truncated fit is the first to fail because it has a parameter more.")
+    if (max(Phigher) < 5) warning("Too few data levels of degrees (< 5) for higher trophic level! Fitting makes no sense! The truncated fit is the first to fail because it has one parameter more.")
 
     fitdd <- function(...){
     	 # Obviously, an intercept "b" has to be fitted, too.
     	 # This was wrongly omitted in the versions <1.09!
+				
         start.trials.b <- c(0.01, .5, 1, 2, 4, 10, 100, 1000)
         start.trials.gamma <- c(0.01, 0.1, 1, 10)
         starts <- expand.grid(start.trials.b, start.trials.gamma)
@@ -40,15 +41,18 @@ function(web, plot.it=TRUE, pure.call=TRUE, silent=TRUE){
         		TPL <- try(nls(P ~ b*(k^(-gamma))*exp(-k/kx), start=list(gamma=coef(PL)[1], b=coef(PL)[2], kx=kx.try), ...), silent=silent)
         		if (!inherits(TPL, "try-error")) break;
          } 
-        } else {TPL <- try(sqrt("w"))} #only to produce an error!
+        } else {TPL <- try(sqrt("w"), silent=TRUE)} #only to produce an error!
         
         list(EXP, PL, TPL)
     }
 
-    fitl <- fitdd(data=Plower, nls.control(maxiter=1000))
-    fith <- fitdd(data=Phigher, nls.control(maxiter=1000))
+	# for 3 or fewer data points, fitting is silly. Thus, a first check is performed that returns try-errors if too few data points are found:
+	if (length(Plo) < 4){fitl <- list(try(sqrt("w"), silent=TRUE))} else {fitl <- fitdd(data=Plower, nls.control(maxiter=1000))}
+	if (length(Phi) < 4){fith <- list(try(sqrt("w"), silent=TRUE))} else {fith <- fitdd(data=Phigher, nls.control(maxiter=1000))}
+#was:    fith <- fitdd(data=Phigher, nls.control(maxiter=1000))
 
-    indexl <- which(sapply(fitl, function(x) !inherits(x, "try-error"))!=0)
+	# set NAs right for plotting:
+	indexl <- which(sapply(fitl, function(x) !inherits(x, "try-error"))!=0)
     fitnew <- fitl[indexl]
     
     indexh <- which(sapply(fith, function(x) !inherits(x, "try-error"))!=0)
@@ -73,19 +77,27 @@ function(web, plot.it=TRUE, pure.call=TRUE, silent=TRUE){
     rownames(res.out) <- c("exponential", "power law", "truncated power law")
     colnames(res.out) <- c("Estimate", "Std. Error", "Pr(>|t|)", "R2", "AIC")
 
-    # lower trophic level:
+	# if all fits are "try-error":
+	if (all(sapply(fitl, function(x) inherits(x, "try-error")))) only.na.low <- TRUE else only.na.low <- FALSE
+	if (all(sapply(fith, function(x) inherits(x, "try-error")))) only.na.high <- TRUE else only.na.high <- FALSE
+	
+	# lower trophic level:
     resl.out <- res.out
-    resl2 <- t(sapply(fitl[indexl], function(mod) try(c(R2=cor(eval(mod$data)$P, predict(mod)), AIC=AIC(mod)) )))
-    resl.out[indexl, 4:5] <- resl2
-    resl1 <- t(sapply(fitl[indexl], function(mod) coef(summary(mod))[1, c(1,2,4)]))
-    resl.out[indexl, 1:3] <- resl1
+	if (!only.na.low){ # catch the case that none of the regressions converges:
+		resl2 <- t(sapply(fitl[indexl], function(mod) try(c(R2=cor(eval(mod$data)$P, predict(mod)), AIC=AIC(mod)), silent=TRUE )))
+		resl.out[indexl, 4:5] <- resl2
+		resl1 <- t(sapply(fitl[indexl], function(mod) coef(summary(mod))[1, c(1,2,4)]))
+		resl.out[indexl, 1:3] <- resl1
+	}
 
     # higher trophic level:
     resh.out <- res.out
-    resh2 <- t(sapply(fith[indexh], function(mod) try(c(R2=cor(eval(mod$data)$P, predict(mod)), AIC=AIC(mod)) )))
-    resh.out[indexh, 4:5] <- resh2
-    resh1 <- t(sapply(fith[indexh], function(mod) coef(summary(mod))[1, c(1,2,4)]))
-    resh.out[indexh, 1:3] <- resh1
+    if (!only.na.high){ # catch the case that none of the regressions converges:
+		resh2 <- t(sapply(fith[indexh], function(mod) try(c(R2=cor(eval(mod$data)$P, predict(mod)), AIC=AIC(mod)), silent=TRUE )))
+		resh.out[indexh, 4:5] <- resh2
+		resh1 <- t(sapply(fith[indexh], function(mod) coef(summary(mod))[1, c(1,2,4)]))
+		resh.out[indexh, 1:3] <- resh1
+	}
 
     list("lower trophic level dd fits"=resl.out, "higher trophic level dd fits"=resh.out)
 
